==> romancal-0.14.0-py3-none-any.whl: romancal/stpipe/integration.py <==
"""
Entry point implementations.
"""


def get_steps():
    """
    Return tuples describing the stpipe.Step subclasses provided
    by this package.  This method is registered with the stpipe.steps
    entry point.

    Returns
    -------
    list of tuple (str, str, bool)
        The first element each tuple is a fully-qualified Step
        subclass name.  The second element is an optional class
        alias.  The third element indicates that the class
        is a subclass of Pipeline.
    """
    # Unit tests ensure that this list is kept in sync with the actual
    # class definitions.  We need to avoid importing romancal.pipeline and
    # romancal.step to keep the CLI snappy.
    return [
        ("romancal.pipeline.ExposurePipeline", "roman_elp", True),
        ("romancal.pipeline.HighLevelPipeline", "roman_hlp", True),
        ("romancal.step.DarkCurrentStep", None, False),
        ("romancal.step.DQInitStep", None, False),
        ("romancal.step.FlatFieldStep", None, False),
        ("romancal.step.JumpStep", None, False),
        ("romancal.step.LinearityStep", None, False),
        ("romancal.step.PhotomStep", None, False),
        ("romancal.step.RampFitStep", None, False),
        ("romancal.step.RefPixStep", None, False),
        ("romancal.step.SaturationStep", None, False),
        ("romancal.step.AssignWcsStep", None, False),
        ("romancal.step.OutlierDetectionStep", "outlier_detection", False),
        ("romancal.step.SourceDetectionStep", None, False),
        ("romancal.step.SkyMatchStep", "skymatch", False),
        ("romancal.step.TweakRegStep", "tweakreg", False),
        ("romancal.step.ResampleStep", "resample", False),
    ]

==> romancal-0.16.3-py3-none-any.whl: romancal/stpipe/integration.py <==
"""
Entry point implementations.
"""


def get_steps():
    """
    Return tuples describing the stpipe.Step subclasses provided
    by this package.  This method is registered with the stpipe.steps
    entry point.

    Returns
    -------
    list of tuple (str, str, bool)
        The first element each tuple is a fully-qualified Step
        subclass name.  The second element is an optional class
        alias.  The third element indicates that the class
        is a subclass of Pipeline.
    """
    # Unit tests ensure that this list is kept in sync with the actual
    # class definitions.  We need to avoid importing romancal.pipeline and
    # romancal.step to keep the CLI snappy.
    return [
        ("romancal.pipeline.ExposurePipeline", "roman_elp", True),
        ("romancal.pipeline.MosaicPipeline", "roman_mos", True),
        ("romancal.step.DarkCurrentStep", None, False),
        ("romancal.step.DQInitStep", None, False),
        ("romancal.step.FlatFieldStep", None, False),
        ("romancal.step.FluxStep", None, False),
        ("romancal.step.JumpStep", None, False),
        ("romancal.step.LinearityStep", None, False),
        ("romancal.step.PhotomStep", None, False),
        ("romancal.step.RampFitStep", None, False),
        ("romancal.step.RefPixStep", None, False),
        ("romancal.step.SaturationStep", None, False),
        ("romancal.step.AssignWcsStep", None, False),
        ("romancal.step.OutlierDetectionStep", "outlier_detection", False),
        ("romancal.step.SourceDetectionStep", None, False),
        ("romancal.step.SkyMatchStep", "skymatch", False),
        ("romancal.step.TweakRegStep", "tweakreg", False),
        ("romancal.step.ResampleStep", "resample", False),
        ("romancal.step.SourceCatalogStep", "source_catalog", False),
    ]
